# $Id: vocabulary.py,v 1.140 2003/02/10 10:25:20 jmp Exp $
#
# Copyright 2001, 2002 by Fle3 Team and contributors
#
# This file is part of Fle3.
#
# Fle3 is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Fle3 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Fle3; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""Contains the english translations for all Fle3 printable strings."""

# How to do a new translation:
#
# 1. Copy this file into a new file, appending the language code after it, so
# you get something like "vocabulary_es.py" for Spanish and so on.
#
# 2. Edit the new file, translating the second portion of each line. The
# first portion is the keyword, which you shouldn't touch. The second is the
# translation that should be translated to the target language. The third
# is the supplementary instruction, that should help you do the translations.
#
# 3. Please note that the file is in Python code and needs to follow certain
# syntax rules:
#  - Strings can either be quoted by singles quotes (') or double quotes (").
#    If you need to use either of these quotation marks in your translation,
#    make sure that you use the other quotation mark to surround the string.
#    If you need to use both quotation marks in the same translation string,
#    you can surround the string with triple quotes (''' or """), which
#    allows you to use either of the quotation marks inside the string.
#  - Line breaks are not allowed inside strings, so make sure you don't
#    use an editor that wraps lines. You can have line breaks between
#    strings, though.
#
# 4. If you need to use special characters (outside of the 127 character
# ASCII range), you have several choices:
#
# A. Write in your native encoding (whatever suits you best). This requires
#    that you change the "charset_encoding" keyword in the "common" module to
#    the encoding type you will use. This document is written in iso8859-1,
#    although as english does not contain special characters, it could be
#    in utf-8 as well without any differences.
#    Most European languages are easiest to write in iso8859-1.
#
# B. Write in utf-8 encoded unicode. If your editor can save files in utf-8,
#    use that feature. If not, you can add the special characters manually
#    with the \x escape sequences. Make sure you remove the keyword
#    "charset_encoding" from the "common" module, or change its value to
#    "utf-8" so that the strings are interpreted correctly.
#    'key': ('\xe3\x82\xaa','This is the katakana letter O,encoded in utf-8.'),
#
# C. Write in unicode. Each unicode string starts with u followed by the
#    quotes. Each unicode character starts with \u followed by the code in
#    hexadecimal notation. The value of the "charset_encoding" keyword
#    is irrelevant if you use unicode all the way.
#    'key': (u'\u30aa','This is the katakana letter O, encoded in unicode.'),
#
# 5. Check your translation. If you have Python installed and you've
#    downloaded Fle3 sources, you can execute "python TranslationLint.py"
#    which will check through all the translation files and will produce
#    an error if there is a syntax error.
#    If you have installed Fle3, you can test the translation yourself
#    by going to Zope Management and selecting the Tools tab in your FLE
#    instance, and clicking on "reload_translations". After this you
#    should be able to select your translation from user preferences
#    and see the translated strings.
#

common = {
    'language_name': ('English', 'Name of this language'),
    'charset_encoding': ('iso8859-1','Encoding used in this translation (if missing, utf-8 is assumed'),
    'WebTop': ('WebTop','Main tab for webtop'),
    'Knowledge_Building': ('Knowledge Building','Main tab for knowledge building'),
    'Course_Management': ('Course Management','Main tab for course management'),
    'User_Management': ('User Management','Main tab for user management'),
    'Jamming': ('Jamming', 'Main tab for jamming'),
    'Type_Management': ('Knowledge Type Management','Heading'),
    'cancel': ('Cancel','Button label'),
    'submit': ('Submit','Button label'),
    'remove': ('Remove','Button label'),
    'next': ('Next ->','Label for button'),
    'previous': ('<- Previous','Label for button'),
    'quick_submit': ('Quick submit',''),
    'ok': ('Ok','Button label'),
    'save': ('Save','Button label'),
    'create': ('Create','Button label'),
    'search': ('Search','Button label'),
    'webtop': ('Webtop',''),
    'description': ('Description','Label'),
    'short_date_format_display': ('YYYY-MM-DD', 'String displayed as clue when entering a date'),
    'short_date_format': ('%Y-%m-%d', 'Format string for short dates. DO NOT CHANGE THE PLACE HOLDER NAMES! You can change their order and the delimiting characters if you want.'),
    'timestamp_format': ('%H:%M %Y-%m-%d', 'Format string for long timestamps. DO NOT CHANGE THE PLACE HOLDER NAMES! You can change their order and the delimiting characters if you want.'),
    'invite': ('Invite',''),
    'add': ('Add',''),
    'today': ('Today',''),
    'yesterday': ('Yesterday',''),
    'groupfolder': ('course folder','Heading'),
# v1.9:
    'dtml_reloaded': ('DTML reloaded','Title for message dialog'),
    'dtml_files_reloaded': ('DTML files reloaded for this object','Message dialog text'),
    'dtmls_reloaded': ('DTMLs reloaded','Title for message dialog'),
    'dtmls_files_reloaded': ('All DTML files reloaded','Message dialog text'),
    'css_reloaded': ('Style sheets reloaded','Title for message dialog'),
    'css_files_reloaded': ('Style sheet files reloaded for this object','Message text'),
    'error': ('Error',''),
    'warning': ('Warning',''),
# v1.26:
    'invalid_url': ('Invalid url', 'Message title'),
    'invalid_url_message': ('It appears that the URL address you typed is incorrect.<br>Please check that it begins with http://, ftp://, mailto: or other Internet address protocol you want to use. Please note that you cannot just enter web page addresses like "www.myaddress.org" but that you need to specify the protocol first: "http://www.myaddress.org". If you are not sure about the protocol for your web address, try copying and pasting the full URL from your web browser.', 'Message text'),
    'invalid_name': ('Invalid name','Message title'),
    'give_valid_name': ('Please enter a valid name','Message text'),
    'name_taken': ('Another item already has the name "%s". Please enter another name.','Message text, name inserted inside'),
# v1.31:
    'edit': ('Edit','Button label'),
    'you_are_in': ('You are in:', 'Heading, without trailing colon - keep in translation if needed'),
    'required_field_missing': ("You didn't fill all the required fields.", 'Erro message text'),
    'confirmation': ('Confirmation', 'Title for confirmation dialogs'),
    'invalid_input': ('Invalid input', 'Message title'),
    'invalid_fields': ('The following fields have invalid input', 'Message text followed by a list of field names'),
    'select_item_first_common': ('Select some items first', 'Message text'),
    'link_to_webtop': ('Create link on WebTop','Link'),
    'proxy_to_webtop': ('Link course folder to WebTop','Link'),
    'export': ('Export','Button label'),
    'import': ('Import','Button label'),
    'importing': ('Importing','Heading start'),
    'megabyte': ('MB', 'Abbreviation for megabyte'),
    'kilobyte': ('kB', 'Abbreviation for kilobyte'),

    'logout': ('Logout', 'Link for logging out, also heading in logout dialogs'),
    'logout_pre2': ("To log out, either close your browser or press the <b>Logout</b> button below. When your browser asks for a login name and password, just press <b>Cancel</b> (on some browsers you must first submit an invalid password and cancel the second prompt). This will clear your login information from your browser's cache",'Instructions on logging out'),
    'logout_post': ("You have been logged out.",'Logout notification'),
    'login': ('Login','Link to log in'),
    'any': ('Any', 'Label used in search forms'),
    'course': ('course', 'Part of location path'),
    }

kb = {
    'course_info': ('Course information', 'Label for link to course details'),
    'create_context': ('Create course context', 'Link to create new course context'),
    'hide_context': ('Hide context', 'Link to hide a context from view'),
    'show_context': ('Show context', 'Link to show a hidden context'),
    'new_notes': ('new notes', 'Label for showing the number of new notes, eg. "5 new notes"'),
    'notes_total': ('notes', 'Label for showing the number of notes'),
    'full_description': ('full description...', ''),
    'course': ('course',"String 'course' in context display"),
    'context': ('context',"String 'context' in context display"),
    'thread': ('thread',"String 'thread' in context display"),
    'note': ('note',"String 'note' in context display"),
    'start_thread': ('Start thread','Link'),
    'short_description': ('Short description','Label'),
    'long_description': ('Long description','Label'),
    'full_description': ('Full description','Label'),
    'select': ('Select','Start of sentence, followed by a drop-down list of available knowledge types'),
    'knowledge_type': ('knowledge type','Label'),
    'add_note': ('Add note','Button label'),
    'show_notes': ('Show notes','Heading start'),
    'show_thread': ('as thread','heading finish'),
    'show_type': ('by knowledge type','heading finish'),
    'show_author': ('by person','heading finish'),
    'show_date': ('by date','heading finish'),
    'select_course': ('Select course','Label, followed by a drop-down list of available courses'),
    'change': ('Change','Button label'),
    'creating_context': ('Creating course context in','Title, followed by the course name'),
    'editing_context': ('Editing course context in','Title, followed by the course name'),
    'title_of_context': ('Title of the course context','Label'),
    'type_set': ('Knowledge type set','Label'),
    'creating_note_in': ('Creating note in','Title, followed by course context name'),
    'course_context': ('course context','Label for course context'),
    'you_are_replying_to': ('You are replying to','Label'),
    'title_of_note': ('Title for the note','Label'),
    'message_body': ('Message body','Label'),
    'current_image': ('Current image','Label'),
    'replace_with': ('Replace with','Label for image replacement in note edit'),
    'add_image': ('Add image','Label'),
    'title_of_image': ('Title for the image','Label'),
    'add_link': ('Add link (URL)','Label'),
    'title_of_link': ('Title for the link','Label'),
    'preview': ('Preview','Button label'),
    'previewing_note': ('Previewing the note in','Title/heading, followed by course context name'),
    'publish': ('Publish','Button label'),
    'search_kb': ('Search Knowledge Building','Link label'),
    'searching_kb': ('Searching Knowledge Building notes','Label'),
    'search_author': ('Author','Label'),
    'search_notes_words': ('Notes that contain words','Label'),
    'search_context': ('Course context','Label'),
    'search_tt': ('Knowledge types','Label'),
    'search_note': ('Note','Label'),
    'current_note': ('Current note','Label'),
# v1.19:
    'you_didnt_select_type': ("You didn't select any knowledge type.",'Title'),
    'go_back': ('Go back','Start of message, rendered into a link'),
    'and_select_type': ('and select the knowledge type for your note.','Rest of message'),
    'inline_notes': ('Show bodies of all notes','Link'),
    'outline_notes': ('Hide bodies of all notes','Link'),
    'view_info': ('view information','Part of location bar'),
    'edit_context': ('Edit course context','Link'),
# v1.27:
    'to_note': ('to note','Part of a message'),
# v1.31:
    'full_thread_no': ('Show only starting notes', 'Link'),
    'full_thread_yes': ('Show full thread', 'Link'),
    'remove': ('Remove note','Button label for removing notes'),
    'restore': ('Restore note','Button label for restoring notes'),
    'remove_form_title': ('Removing note','Title for note removing form'),
    'remove_form_label': ('Removing note','Explanation in remove form, followed by note subject'),
    'removed_msg': ('Message is removed','Message shown to the teacher when she has removed a note.'),
    'remove_verify2': ('Are you sure you want to remove this message? Your name, this date and the explanation you supply below will be stored and displayed along with the removal notice to anyone viewing this note.','Verification message shown when removing is attempted'),
    'remove_explanation': ('Explanation for removal','Label for removee explanation text area'),
    'removed_subject': ('Removed','Title/subject for removed notes'),
    'removed_body': ('This message has been removed by %s at %s.',"Body for removed messages. First placeholder is replaced by remover's name and the second by the date"),
    'notes_from_day': ('Notes from','Start of heading, followed by a date'),
    'previous': ('Previous', 'Link label'),
    'next': ('Next', 'Link label'),
    'who_has_read': ('Who has read this note?', 'Link label'),
    'last_read': ('Last read', 'Label'),
    'times_read': ('Times read', 'Label'),
    'back': ('&lt; back', 'Link label'),
    'unread_to_read_msg': ('All notes in a thread marked as read.', 'title and message in a message dialog'),
    'mark_notes_read': ('Mark all notes as read', 'text in a button'),
    'creating_groupfolder': ('Creating course folder in','Heading start'),
    'title_groupfolder': ('Title of course folder','Label'),
# v1.87:
    'flea_asks': ('Flea asks','Heading displayed in the scaffolding check list. Flea is the name of the FLE-helper.'),
    'change_type': ('Change the Knowledge Type?', 'Question at the end of the scaffolding check list.'),
    'no_change_possible': ('This is the only type allowed here.','Text displayed when there is only one possible follow-up type and the type cannot be changed.'),
    'change': ('Change', 'Button label'),
    'down_to_note': ('Down', 'Link label'),
    'use_roleplay': ('Use roleplay in this context','Label for option deciding if the course context creator wants to use roleplaying roles for postings in this context.'),
    'setup_roleplay': ('Setting up roleplaying roles','Title for form, where roleplaying roles are set'),
    }

webtop = {
    'users_courses': ("Courses","Heading for user's course list"),
    'new_notes': ('new notes','Label for displaying the number of new notes in a course'),
    'total_notes': ('total','Label for displaying the total number of notes in a course'),
    'add_folder': ("Add folder",""),
    'add_document': ("Add document",""),
    'add_link': ("Add link",""),
    'create_memo': ("Create memo",""),
    'type': ('Type','Link for sorting by type'),
    'title': ('Title','Link for sorting by title'),
    'date': ('Date','Link for sorting by date'),
    'size': ('Size', 'Link for sorting by size'),
    'remove': ('Remove','Button label'),
    'restore': ('Restore','Button label'),
    'rename': ('Rename', 'Button label'),
    'copy': ('Copy','Button label'),
    'cut': ('Cut','Button label'),
    'paste': ('Paste','Button label'),
    'delete': ('Delete','Button label'),
    'select_all': ('Select all', 'Button label'),
    'trash': ('Trash','Label for trashcan'),
    'empty_trash': ('Empty trash','Button label'),
    'adding_folder': ('Adding folder','Heading'),
    'title_of_folder': ('Title of the folder','Label'),
    'viewing_memo': ('Viewing memo', 'Title'),
    'creating_memo': ('Creating memo','Title'),
    'editing_memo': ('Editing memo','Title'),
    'title_of_memo': ('Title of the memo','Label'),
    'content': ('Contents','Label'),
    'show_memo_contents': ('Show only memo contents','Link'),
    'adding_link': ('Adding link','Title'),
    'title_of_link': ('Title of the link','Label'),
    'url': ('URL',''),
    'document_uploaded': ('Document uploaded.','Status message'),
    'adding_document': ('Adding document', 'Title'),
    'upload_document': ('Upload document','Label'),
    'title_of_document': ('Title of the document','Label'),
    'search_wt': ('Search WebTops','Link label'),
    'searching_wt': ('Searching WebTops','Label'),
    'search_results': ('Search results','Label'),
    'new_search': ('New search','Label'),
    'search_title': ('Title','Label'),
    'search_owner': ('Owner','Label'),
    'search_words': ('Objects that contain words','Label'),
    'search_object': ('Object','Label'),
    'search_folder': ('Folder','Label'),
    'viewing_search_results': ('viewing search results','Label in the location path'),
    'anyone': ('Anyone','Label'),
# v1.9:
    'webtop_link_added': ('WebTop link added','Message title'),
    'added_webtop_link': ('A link %s "%s" was created on your Webtop. Click OK to return to the previous page.','Message text; "to type" and "name" inserted into placeholders (2)'),
    'proxy_added': ('Course folder added', 'Message title'),
    'added_proxy': ('The course folder of course %s is now visible on your Webtop. Click OK to return to the previous page.', 'Message text, course name inserted into placeholder'),
    'no_item_selected': ('No items selected!','Message dialog title'),
    'select_item_first': ('Please select at least one item to perform actions other than paste.','Message dialog message'),
    'no_file_supplied': ('No file supplied.','Message text'),
    'renaming': ('Renaming', 'Title'),
    'invalid_names': ('The following names are invalid:', 'Message dialog messsage'),
    'same_names': ('You gave the same name for several objects.', 'Message dialog message'),
    'names_in_use': ('The following names are already in use:', 'Message dialog message'),
# v1.19:
    'information': ('User information','Link'),
    'preferences': ('Preferences','Link'),
    'editing_preferences': ('Editing preferences','Title'),
    'shared': ('Shared', 'Printed after the name of the group folder'),
    'quota_reached_title': ('Quota limit reached', 'Title'),
    'quota_reached': ('Operation cannot be performed because you have reached quota limit in your WebtTop. Please remove some objects and try again.', 'Message dialog message'),
    'obj_removed': ('(link target has been removed)','This is appended to internal webtop links that point to objects that no longer exist.'),
    'back': ('&lt; back', 'Link label'),
    }

coursemgmnt = {
    'course': ('course', 'part of browser title'),
    'courses': ('Courses','Title'),
    'create_course': ('Create course','Link'),
    'edit_course': ('Edit course','Button label'),
    'edit_participants': ('Edit participants','Button label'),
    'creating_course': ('Creating course','Title'),
    'editing_course': ('Editing course','Title'),
    'course_title': ('Course title','Label'),
    'organization': ('Organization','Label'),
    'methods': ('Methods','Label'),
    'starting_date': ('Starting date','Label'),
    'ending_date': ('Ending date','Label'),
    'create_groupfolder': ('Create group folder','Link'),
    'adding_users_to_course': ('Adding users to course','Title, name of course is displayed after this'),
    'if_participants_not_users': ('In case the course participants are not yet Fle3 users','Message'),
    'new_participants_to_system': ('new participants to Fle3 system', 'Part of a phrase'),
    'by_email': ('by e-mail','Part of a phrase'),
    'manually': ('manually','Part of a phrase'),
    'fle_users': ('FLE3 Users','Heading'),
    'down': ('Down','Button label'),
    'up': ('Up','Button label'),
    'teachers': ('Teachers','Heading'),
    'tutors': ('Tutors','Heading'),
    'students': ('Students','Heading'),
    'add_button': ('Add ->','Button label'),
    'remove_button': ('<- Remove','Button label'),
    'viewing_course': ('viewing course','Part of a phrase in location path'),
    'information': ('information','Part of a phrase in location path'),
# v1.9:
    'no_course_selected': ('No course selected!','Message dialog title'),
    'select_course_first': ('Please select a course from the course list.','Message dialog message'),
    'set_published': ('Knowledge type set published','Message dialog title/text'),
    'users_updated': ('Users updated','Message dialog title/message'),
    'select_some_users': ('Please select some users','Message dialog title/message'),
# v1.19:
    'edit_course_info': ('Edit course information','Link'),
    'edit_course_participants': ('Edit course participants','Link'),
    'date': ('Date','Label, followed by the starting and ending date of the course.'),
    'course_participants': ('Course participants','Label'),
    'type_sets': ('Knowledge type sets','Label, plural'),
    'delete': ('Delete','Button label'),
# v1.31:
    'add_typeset': ('Add knowledge type set','Link'),
    'tt_yellow': ('Yellow','Knowledge type colour name'),
    'tt_yellowlt': ('Light yellow','Knowledge type colour name'),
    'tt_orange': ('Orange','Knowledge type colour name'),
    'tt_orangelt': ('Light orange','Knowledge type colour name'),
    'tt_red': ('Red','Knowledge type colour name'),
    'tt_pink': ('Pink','Knowledge type colour name'),
    'tt_purple': ('Purple','Knowledge type colour name'),
    'tt_blue': ('Blue','Knowledge type colour name'),
    'tt_bluelt': ('Light blue','Knowledge type colour name'),
    'tt_aqua': ('Aqua','Knowledge type colour name'),
    'tt_green': ('Green','Knowledge type colour name'),
    'tt_greenlt': ('Light green','Knowledge type colour name'),
    'tt_gray': ('Gray','Knowledge type colour name'),
    'tt_white': ('White','Knowledge type colour name'),
    'edit_typeset': ('Editing Knowledge type set','Heading'),
    'create_typeset': ('Creating Knowledge type set','Heading'),
    'form': ('Form','Start of heading'),
    'title': ('Title','Start of label'),
    'of_typeset': ('of the knowledge type set','Ending of label'),
    'abbreviations_and_icons': ('abbreviations and icons','Ending for heading'),
    'type': ('Knowledge type','Label'),
    'types': ('Knowledge types','Title'),
    'types_management': ('Knowledge types management','Title'),
    'abbreviation': ('Abbreviation','Label'),
    'color': ('Colour','Label'),
    'icon': ('Icon','Label'),
    'starting_phrase': ('Starting phrase','Label'),
    'checklist': ('Check list','Label'),
    'no_types_entered': ("You haven't entered any knowledge types. A set must include at least one type.",'Error message for when a new set is created with no types'),
    'restrictions_of_use': ('Restrictions of use','Heading sentence.'),
    'that_can_start_thread': ('that can start a discussion','End of label'),
    'viewing': ('viewing','Part of location bar'),
    'new_typeset_from': ('Duplicate and edit knowledge type set','Link, followed by knowledge type set name'),
    'unfinished': ('Unfinished','Label'),
    'manage_types': ('Manage knowledge types','Link'),
    'finalize_typeset': ('Change status to Finished','Button label'),
    'are_you_sure': ('Are you sure you want to delete the following courses:' , 'Message dialog message'),
    'are_you_sure_ctx': ('Are you sure you want to delete this course context:' , 'Message dialog message'),
    'are_you_sure_tts': ('Are you sure you want to delete the following knowledge type sets:' , 'Message dialog message'),
    'typeset_importing': ('Please select the zipped export file containing the knowledge type sets you wish to import.','Instructions for typeset importing'),
    'typesets_imported': ('New knowledge type sets have been imported.','Message'),
    'import_typeset': ('Import knowledge type set','link'),
    'course_importing': ('Please select the zipped export file containing the courses you wish to import.','Instructions for course importing'),
    'courses_imported': ('New courses have been imported.','Message'),
    'import_course': ('Import courses','link'),
    'course_imported': ('(imported)','Appended to imported course names.'),
    }

usermgmnt = {
    'user': ('user', 'part of browser title'),
    'adding_users': ('Adding users', 'Title'),
    'required_field': ('Required field',''),
    'nickname': ('Nickname','Label'),
    'user_account': ('User account','Label'),
    'Confirm': ('Confirm',''),
    'you_are_removing': ('You are removing',''),
    'invite_user': ('Invite user',''),
    'invite_users': ('Invite users','Heading for invitation form'),
    'email_addresses': ('E-mail addresses',''),
    'separate_with_comma': ('( separate with: , )',''),
    'Invitation_message': ('Invitation message',''),
    'Invitation_language': ('Invitation language', ''),
    'Courses_to_invite_to': ('Courses to invite to', ''),
    'Freeze': ('Freeze',''),
    'Remove': ('Remove',''),

    'role': ('Role', 'label'),
    'role_staff': ('Staff', 'Global role stuff'),
    'role_user': ('User', 'Global role user'),
    'role_fleadmin': ('FLE Admin', 'Global role fleadmin'),

    'invite_again': ('Invite again','Button label'),
    'warning': ('Warning','Heading'),
    'want_remove_users': ('Do you want to remove the following users?','Complete question'),
    'invited_user_manage': ('Management of invited users','Title'),

    'info_user': ('Information about ','Title for user info page, prefix before user name'),
    'edit_user': ('Edit user','Link'),
    'editing': ('Editing','Heading for user edit, inserted before user name'),
    'image_of_user': ('Image of the user','Label'),
    'upload_image_of_user': ('Upload your image','Label'),
    'or_link_to_image': ('or give a link to an image','Label, continuing from the upload label'),
    'webtop_bg': ('Select a WebTop background image', 'Label'),
    'upload_webtop_bg': ('or upload your own background image', 'Label, continuing from the webtop_bg'),
    'show_pending_users': ('Check invites',''),
    'add_user': ('Add user',''),
    'Unfreeze': ('Unfreeze',''),
    'Users': ('Users',''),
    'gsm': ('Mobile',''),
    'last_name': ('Last name',''),
    'first_name': ('First name',''),
    'city': ('City',''),
    'organization': ('Organization',''),
    'professional_interests': ('Professional interests',''),
    'email': ('Email',''),
    'phone': ('Phone',''),
    'language': ('Language',''),
    'url_to_photo': ('URL to picture',''),
    'country_menu_default': ('Select country',''),
    'group_menu_default': ('Select group','Default value for drop-down menu'),
    'address': ('Address',''),
    'address1': ('Address line 1',''),
    'address2': ('Address line 2',''),
    'personal_interests': ('Personal interests',''),
    'quote': ('Quote',''),
    'homepage': ('Homepage',''),
    'upload': ('Upload',''),
    'group': ('Group',''),
    'password': ('Password',''),
    'background': ('Background',''),
    'country': ('Country',''),
# v1.9:
    'reserved_nickname': ('Sorry. That nickname is already taken.', 'Message'),
    'password_mismatch': ("Supplied passwords don't match.",'Message'),
    'could_not_send_invitation': ('Could not send invitation message. Please check that your MailHost object is configured properly.','Error message'),
    'invitations_sent': ('Invitations sent','Message title'),
    'invitations_sent_to': ('Invitations sent to %s. ','Message, email list is inserted into the placeholder.'),
    'invitations_not_sent_to': ('Invitations were not sent to: %s.', 'Message, email list is inserted into the placeholder.'),
    'users_removed': ('Users removed','Message title'),
    'removed_users': ('Users removed: %s','Message, list inserted inside'),
    'not_removed_users': ('Unable to remove these users: %s','Message, list inserted inside'),
    're_invitations_sent': ('Re-invitations sent','Message title'),
    're_invitations_sent_to': ('Re-invitations sent to %s users. ','Message, email count is inserted into the placeholder.'),
    'pending_users_removed': ('Pending users removed','Message title'),
    'pending_removed_users': ('Pending users removed: %s','Message, list inserted inside'),
    'pending_not_removed_users': ('Unable to remove these pending users: %s','Message, list inserted inside'),
    'invitation_subject': ('Invitation to FLE','Subject for invitation messages'),
    'invitation_header': ('Invitation','Header for invitation messages'),
    'invitation_footer': ('Please visit: ','Footer for invitation messages; followed by the URL'),
# v1.15:
    'welcome_message': ('Welcome to FLE. Please fill in your user information below.','Welcome message used in invitation registration form'),
    'uname': ('Login name','Label used for user login name in several places'),
    'registration_failed': ('Registration failed',"Title used when invited user can't register."),
    'invitation_key_used': ("This invitation URL has already been used or is no longer valid. If you have not been able to register, please contact your teacher to get another invitation.",'Message telling that the registration url has been used.'),
    'authorization_failed': ('Authentication keys are invalid',"Message telling that the authentication key isn't valid."),
# v1.19:
    'after_submit_give_name_and_passwd2': ('After hitting "Submit" give your login name and password.','Message'),
# v1.21:
    'frozen': ('Frozen','User status code'),
# v1.22:
    'no_email': ('No email address', 'Message title'),
    'no_email_explanation': ("You can't send email because you haven't set your email address.", 'Message text'),
    'passwd_changed': ('Password changed', 'Message title'),
    'passwd_changed_explanation2': ('You changed your password: Your browser will ask for a login name and password.', 'Message text'),
    }

jam = {
    'add_jam_session': ('Add jam session', 'link'),
    'jam_sessions': ('Jam sessions:', 'a list of jam session will listed after/under this label'),
    'jam_session': ('jam session', ''),
    'annotations': ('annotations', ''),
    'continue_with_version': ('Continue with your version', 'button label'),
    'artefact': ('artefact', ''),
    'viewing_annotations': ('viewing annotations', ''),
    'Annotations': ('Annotations:', 'Label, followed by a list of annotations under it'),
    'add_annotation': ('Add annotation', 'link'),
    'adding_jam_session': ('Adding jam session', ''),
    'edit_jam_session': ('Edit jam session', ''),
    'editing_jam_session': ('Editing jam session', ''),
    'title_of_jam_session': ('Title of jam session', 'label'),
    'type_of_jam_session': ('Type of jam session', 'label'),
    'mutate_on_previous': ('Mutate on previous', 'type of jam session'),
    'explore_possibilities': ('Explore possibilities', 'type of jam session'),
    'diverge_and_converge': ('Diverge & Converge', 'type of jam session'),
    'description_of_jam_session': ('Description of jam session', 'label'),
    'upload_the_starting_artefact': ('Upload the starting artefact', 'label'),
    'title_of_the_starting_artefact': ('Title of the starting artefact', 'label'),
    'annotation_of_the_starting_artefact': ('Annotation for the starting artefact', 'label'),
    'adding_artefact': ('Adding artefact', ''),
    'title_of_the_artefact': ('Title of the artefact', 'label'),
    'upload_file': ('Upload file', 'label'),
    'you_adding_annotation': ('You are adding annotation to the artefact', 'message in adding annotations form'),
    'adding_annotation': ('Adding annotation to', ''),
    'to_jam_session': ('to jam session', 'Part of a message'),
    'to_jam_artefact': ('to jam artefact', 'Part of a message'),
    'unread_artefacts': ('new artefacts', 'There is a number before this message'),
    'total_artefacts': ('total', 'There is a number before this message'),
    'are_you_sure_jam_sessions': ('Are you sure you want to delete the following jam sessions:' , 'Message dialog message'),
    'are_you_sure_jam_session': ('Are you sure you want to delete this jam session with %s artefacts?', 'Message dialog message. Placeholder is replace with number of jam artefacts'),
    'remove_artefact': ('Remove artefact', 'Button label for removing jam artefact'),
    'restore_artefact': ('Restore artefact', 'Button label for restoring jam artefact'),
    'remove_annotation': ('Remove selected annotations', 'Button label for removing jam annotations'),
    'restore_annotation': ('Restore selected annotation', 'Button label for restoring jam annotations'),
    'removed_name': ('Removed', 'Title/name for removed jam artefact'),
    'removed_message': ('This artefact has been removed by %s at %s.', "First placeholder is replaced by remover's name and the second by the date"),
    'removed_msg': ('Artefact is removed', 'Message shown to the teacher when she has removed an artefact.'),
    'removed_annotation_msg': ('Annotation is removed', 'Message shown to the teacher when she has removed an annotation.'),
    'remove_verify': ('Are you sure you want to remove this artefact? Your name and this date will be stored and displayed along with the notice about the removal to everyone viewing this artefact.','Verification message shown when removing is attempted'),
    'remove_annotations_verify': ('Are you sure you want to remove the annotations you selected? Your name and this date will be stored and displayed along with the notice about the removal to everyone viewing annotations.','Verification message shown when removing is attempted'),
    'removed_annotation_body': ('This annotation has been removed by %s at %s.',"Body for removed annotation. First placeholder is replaced by remover's name and the second by the date"),
    'search_jam': ('Search Jamming', 'Link label'),
    'searching_jam': ('Searching jam artefacts', 'Label'),
    'search_artefact_name': ('Artefact name', 'Label in search form'),
    'search_artefact_author': ('Author', 'Label for author of artefact in search form'),
    'search_annotation_words': ('Annotations contain words', 'Label in search form (those artefacts match whose annotations contains at least one of the given words)'),
    'search_artefact_type': ('Artefact type', 'Label in search form (type is image, audio, text, etc...)'),
    'type_image': ('Image', 'Artefact type'),
    'type_audio': ('Audio', 'Artefact type'),
    'type_text': ('Text', 'Artefact type'),
    'type_html': ('Html', 'Artefact type'),
    'type_video': ('Video', 'Artefact type'),
    'type_archive': ('Archive', 'Artefact type'),
    'search_annotated_by': ('Annotated by', 'Label in search form'),
    'search_results_author': ('Author', 'Heading in search results table'),
    'search_results_jam_artefact': ('Jam artefact', 'Heading in search results table'),
    'search_results_jam_session': ('Jam session', 'Heading in search results table'),

    }

# All vocabularies combined
vocabulary = {'common': common,
              'kb': kb,
              'webtop': webtop,
              'usermgmnt': usermgmnt,
              'coursemgmnt': coursemgmnt,
              'jam': jam,
              }

#EOF
